"""A Python library that supports tox-based development automation pipelines used by other Sun (NeuroAI) lab projects.

See https://github.com/Sun-Lab-NBB/ataraxis-automation for more details.
API documentation: https://ataraxis-automation-api-docs.netlify.app/
Author: Ivan Kondratyev (Inkaros)
"""
